@@ -19,8 +19,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 /* ---------------------------- included header files ---------------------- */
@@ -1185,12 +1184,6 @@ void parse_colorset(int n, char *line)
 					}
 				}
 			}
-			else
-			{
-				fvwm_msg(
-					ERR, "parse_colorset",
-					"error reading root background");
-			}
 			if (image != None)
 			{
 				XDestroyImage(image);
