@@ -10,16 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
-
-/*
- * This module is all original code
- * by Rob Nation
- * Copyright 1993, Robert Nation
- *     You may use this code for any purpose, as long as the original
- *     copyright remains in the source code and all documentation
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 /* IMPORTANT NOTE: Do *not* use any constant numbers in this file. All values
@@ -32,6 +23,8 @@
 
 #include <stdio.h>
 
+#include "libs/Parse.h"
+#include "libs/Strings.h"
 #include "fvwm.h"
 #include "functions.h"
 #include "repeat.h"
