@@ -10,8 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 /* ---------------------------- included header files ---------------------- */
@@ -133,15 +132,15 @@ static void menustyle_copy_face(MenuFace *destmf, MenuFace *origmf)
 	case PixmapMenu:
 	case TiledPixmapMenu:
 		fpa.mask = (Pdepth <= 8)?  FPAM_DITHER:0;
-	
-		if (destmf->u.p) 
+
+		if (destmf->u.p)
 			destmf->u.p = NULL;
 
 		if (origmf->u.p)
 			destmf->u.p = PCacheFvwmPicture(
 				dpy, Scr.NoFocusWin, NULL, origmf->u.p->name,
 				fpa);
-	
+
 		destmf->type = origmf->type;
 		break;
 	default:
@@ -432,6 +431,7 @@ static int menustyle_get_styleopt_index(char *option)
 		"TitleColorset", "HilightTitleBack",
 		"TitleFont",
 		"VerticalMargins",
+		"UniqueHotkeyActivatesImmediate",
 		NULL
 	};
 
@@ -832,7 +832,6 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 	char *option = NULL;
 	char *poption = NULL;
 	char *optstring = NULL;
-	char *nextarg;
 	char *args = NULL;
 	char *arg1;
 	int on;
@@ -840,7 +839,6 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 	MenuStyle *tmpms;
 	Bool is_initialised = True;
 	Bool has_gc_changed = False;
-	Bool is_default_style = False;
 	int val[2];
 	int n;
 	FlocaleFont *new_font = NULL;
@@ -867,10 +865,6 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 	{
 		/* copy the structure over our temporary menu face. */
 		memcpy(tmpms, ms, sizeof(MenuStyle));
-		if (ms == default_menu_style)
-		{
-			is_default_style = True;
-		}
 		free(name);
 	}
 	else
@@ -926,7 +920,7 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 				free(optstring);
 				break;
 			}
-			nextarg = GetNextToken(args, &arg1);
+			(void)GetNextToken(args, &arg1);
 		}
 		poption = option;
 		while (poption[0] == '!')
@@ -1007,6 +1001,13 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 			ST_USE_LEFT_SUBMENUS(tmpms) = 0;
 			ST_IS_ANIMATED(tmpms) = 0;
 			ST_USE_AUTOMATIC_HOTKEYS(tmpms) = 0;
+			/* Pressing a hotkey on an item which only has a
+			 * single entry will activate that action; turning
+			 * those off will make the menu persist until enter or
+			 * space is pressed; the default behaviour is to
+			 * always close the menu and run the action.
+			 */
+			ST_HOTKEY_ACTIVATES_IMMEDIATE(tmpms) = 1;
 			menustyle_free_face(&ST_FACE(tmpms));
 			ST_FACE(tmpms).type = SimpleMenu;
 			if (ST_PSTDFONT(tmpms) && !ST_USING_DEFAULT_FONT(tmpms))
@@ -1601,6 +1602,9 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 				&ST_VERTICAL_MARGIN_BOTTOM(tmpms),
 				0, 0);
 			break;
+		case 63: /* UniqueHotKeyActivatesImmediate */
+			ST_HOTKEY_ACTIVATES_IMMEDIATE(tmpms) = on;
+			break;
 
 #if 0
 		case 99: /* PositionHints */
@@ -1826,6 +1830,8 @@ void menustyle_copy(MenuStyle *origms, MenuStyle *destms)
 
 	/* AutomaticHotkeys */
 	ST_USE_AUTOMATIC_HOTKEYS(destms) = ST_USE_AUTOMATIC_HOTKEYS(origms);
+	ST_HOTKEY_ACTIVATES_IMMEDIATE(destms) =
+		ST_HOTKEY_ACTIVATES_IMMEDIATE(origms);
 	/* Item and Title Spacing */
 	ST_ITEM_GAP_ABOVE(destms) =  ST_ITEM_GAP_ABOVE(origms);
 	ST_ITEM_GAP_BELOW(destms) = ST_ITEM_GAP_BELOW(origms);
@@ -1950,7 +1956,6 @@ void CMD_MenuStyle(F_CMD_ARGS)
 {
 	char *option;
 	char *poption;
-	MenuStyle *dummy;
 
 	GetNextSimpleOption(SkipNTokens(action, 1), &option);
 	poption = option;
@@ -1960,11 +1965,11 @@ void CMD_MenuStyle(F_CMD_ARGS)
 	}
 	if (option == NULL || menustyle_get_styleopt_index(poption) != -1)
 	{
-		dummy = menustyle_parse_style(F_PASS_ARGS);
+		(void)menustyle_parse_style(F_PASS_ARGS);
 	}
 	else
 	{
-		dummy = menustyle_parse_old_style(F_PASS_ARGS);
+		(void)menustyle_parse_old_style(F_PASS_ARGS);
 	}
 	if (option)
 	{
