@@ -10,18 +10,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
-/*
- * This module is all original code
- * by Rob Nation
- * Copyright 1993, Robert Nation
- *     You may use this code for any purpose, as long as the original
- *     copyright remains in the source code and all documentation
- *
- * Changed 09/24/98 by Dan Espen:
+/* Changed 09/24/98 by Dan Espen:
  * - remove logic that processed and saved module configuration commands.
  * Its now in "modconf.c".
  */
@@ -204,28 +196,53 @@ int run_command_file(
 	char *filename, const exec_context_t *exc)
 {
 	char *full_filename;
-	FILE* f;
+	FILE* f = NULL;
 
-	if (filename[0] == '/')
-	{             /* if absolute path */
-		f = fopen(filename,"r");
-		full_filename = filename;
-	}
-	else
-	{             /* else its a relative path */
+	/* We attempt to open the filename by doing the following:
+	 *
+	 * - If the file does start with a "/" then it's treated as an
+	 *   absolute path.
+	 *
+	 *  - Otherwise, it's assumed to be in FVWM_USERDIR OR FVWM_DATADIR,
+	 *    whichever comes first.
+	 *
+	 * - If the file starts with "./" or "../" then try and
+	 *   open the file exactly as specified which means
+	 *   things like:
+	 *
+	 *   ../.././foo is catered for.  At this point, we just try and open
+	 *   the specified file regardless.
+	 *
+	 *  - *Hidden* files in the CWD would have to be specified as:
+	 *
+	 *    ./.foo
+	 */
+	full_filename = filename;
+
+	if (full_filename[0] == '/')
+	{
+		/* It's an absolute path */
+		f = fopen(full_filename,"r");
+	} else {
+		/* It's a relative path.  Check in either FVWM_USERDIR or
+		 * FVWM_DATADIR.
+		 * */
 		full_filename = CatString3(fvwm_userdir, "/", filename);
-		f = fopen(full_filename, "r");
-		if (f == NULL)
+
+		if((f = fopen(full_filename, "r")) == NULL)
 		{
 			full_filename = CatString3(
-				FVWM_DATADIR, "/", filename);
+					FVWM_DATADIR, "/", filename);
 			f = fopen(full_filename, "r");
 		}
 	}
-	if (f == NULL)
-	{
+
+	if ((f == NULL) &&
+		(f = fopen(filename, "r")) == NULL) {
+		/* We really couldn't open the file. */
 		return 0;
 	}
+
 	if (push_read_file(full_filename) == 0)
 	{
 		return 0;
