@@ -10,8 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 /*
   This file is strongly based on the corresponding files from
@@ -1562,7 +1561,7 @@ MatchWinToSM(
 				{
 					free_window_names(ewin, True, False);
 					ewin->name.name = matches[i].wm_name;
-					setup_visible_name(ewin, False);
+					setup_visible_names(ewin, 1);
 				}
 			}
 			SET_NAME_CHANGED(ewin,IS_NAME_CHANGED(&(matches[i])));
