@@ -10,17 +10,9 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
-/*
- * This module is all new
- * by Rob Nation
- * A little of it is borrowed from ctwm.
- * Copyright 1993 Robert Nation. No restrictions are placed on this code,
- * as long as the copyright notice is preserved
- */
 /*
  *
  * fvwm window-list popup code
@@ -604,6 +596,7 @@ void CMD_WindowList(F_CMD_ARGS)
 		iconifiedList = malloc(numWindows*sizeof(t));
 		if (iconifiedList == NULL)
 		{
+			free(windowList);
 			return;
 		}
 	}
@@ -972,10 +965,11 @@ void CMD_WindowList(F_CMD_ARGS)
 					b.total_size.height;
 				dwidth = t->g.frame.width -
 					b.total_size.width;
-				dwidth -= t->hints.base_width;
-				dheight -= t->hints.base_height;
-				dwidth /= t->hints.width_inc;
-				dheight /= t->hints.height_inc;
+
+				dwidth = (dwidth - t->hints.base_width)
+					  /t->orig_hints.width_inc;
+				dheight = (dheight - t->hints.base_height)
+					  /t->orig_hints.height_inc;
 
 				sprintf(loc,"%d",dwidth);
 				strcat(tname, loc);
