@@ -10,34 +10,14 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
-/*
- * This module is all original code
- * by Rob Nation
- * Copyright 1993, Robert Nation
- *     You may use this code for any purpose, as long as the original
- *     copyright remains in the source code and all documentation
- */
 /*
   Changed 02/12/97 by Dan Espen:
   - added routines to determine color closeness, for color use reduction.
   Some of the logic comes from pixy2, so the copyright is below.
 */
-/*
- * Copyright 1996, Romano Giannetti. No guarantees or warantees or anything
- * are provided or implied in any way whatsoever. Use this program at your
- * own risk. Permission to use this program for any purpose is given,
- * as long as the copyright is kept intact.
- *
- * Romano Giannetti - Dipartimento di Ingegneria dell'Informazione
- *                    via Diotisalvi, 2  PISA
- * mailto:romano@iet.unipi.it
- * http://www.iet.unipi.it/~romano
- *
- */
 
 /*
  *
@@ -52,9 +32,12 @@
 
 #include <X11/Xlib.h>
 
-#include <fvwmlib.h>
+#include "fvwmlib.h"
+#include "Graphics.h"
 #include "PictureBase.h"
 #include "PictureUtils.h"
+#include "Fsvg.h"
+#include "Strings.h"
 
 Bool Pdefault;
 Visual *Pvisual;
@@ -208,10 +191,6 @@ GC PictureDefaultGC(Display *dpy, Window win)
 	}
 	if (gc == None)
 	{
-		XGCValues xgcv;
-
-		xgcv.foreground = PictureBlackPixel();
-		xgcv.background = PictureWhitePixel();
 		gc = fvwmlib_XCreateGC(dpy, win, 0, NULL);
 	}
 
@@ -229,7 +208,7 @@ void PictureSetImagePath( const char* newpath )
 	return;
 }
 
-char* PictureGetImagePath()
+char* PictureGetImagePath(void)
 {
 	return imagePath;
 }
@@ -245,11 +224,48 @@ char* PictureGetImagePath()
  */
 char* PictureFindImageFile(const char* icon, const char* pathlist, int type)
 {
+	int length;
+	char *tmpbuf;
+	char *full_filename;
+	const char *render_opts;
+
 	if (pathlist == NULL)
 	{
 		pathlist = imagePath;
 	}
+	if (icon == NULL)
+	{
+		return NULL;
+	}
 
-	return searchPath(pathlist, icon, ".gz", type);
+	full_filename = searchPath(pathlist, icon, ".gz", type);
+
+	/* With USE_SVG, rendering options may be appended to the
+	   original filename, hence seachPath() won't find the file.
+	   So we hide any such appended options and try once more. */
+        if (USE_SVG && !full_filename &&
+	    (render_opts = strrchr(icon, ':')))
+	{
+		length = render_opts - icon;
+		tmpbuf = (char *)safemalloc(length + 1);
+		strncpy(tmpbuf, icon, length);
+		tmpbuf[length] = 0;
+
+		full_filename = searchPath(pathlist, tmpbuf, ".gz", type);
+		free(tmpbuf);
+		if (full_filename)
+		{
+			/* Prepending (the previously appended) options
+			   will leave any file suffix exposed. Callers
+			   who want to access the file on disk will have
+			   to remove these prepended options themselves.
+			   The format is ":svg_opts:/path/to/file.svg". */
+			tmpbuf = CatString3(render_opts, ":", full_filename);
+			free(full_filename);
+			full_filename = safestrdup(tmpbuf);
+		}
+	}
+
+	return full_filename;
 }
 
