@@ -11,8 +11,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 /*
@@ -26,6 +25,7 @@
 #include <X11/Xlib.h>
 #include <fvwmlib.h>
 #include <stdio.h>
+#include "WinMagic.h"
 
 /* Continuously moves and resized window win from start geometry (s_?) to end
  * geometry (e_?). Waits for delay_ms milliseconds after each step except the
@@ -107,7 +107,7 @@ void SlideWindow(
 	is_mapped = False;
 
 	/* Get the mini (re)size hints and do some check consistency */
-	if (use_hints && XGetWMNormalHints(dpy, win, &hints, &dummy))
+	if (use_hints && FGetWMNormalHints(dpy, win, &hints, &dummy))
 	{
 		if (hints.flags & PMinSize)
 		{
