@@ -10,8 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 /* ---------------------------- included header files ---------------------- */
@@ -19,8 +18,11 @@
 #include "config.h"
 #include <stdio.h>
 #include <ctype.h>
+#include <string.h>
 
 #include "charmap.h"
+#include "wcontext.h"
+#include "safemalloc.h"
 
 /* ---------------------------- local definitions -------------------------- */
 
@@ -102,3 +104,39 @@ char charmap_mask_to_char(int mask, charmap_t *table)
 
 	return c;
 }
+
+/* Used from "PrintInfo Bindings". */
+char *charmap_table_to_string(int mask, charmap_t *table)
+{
+	char *allmods;
+	int modmask;
+	char c[2];
+
+	c[1] = 0;
+	modmask = mask;
+	allmods = safemalloc(sizeof(table->value) * 8 + 1);
+	*allmods = 0;
+	for (; table->key !=0; table++)
+	{
+		c[0] = toupper(table->key);
+
+		/* Don't explicitly match "A" for any context as doing so
+		 * means we never see the individual bindings.  Incremental
+		 * matching here for AnyContext is disasterous.*/
+		if ((modmask & table->value) &&
+			(table->value != C_ALL))
+		{
+			/* incremental match */
+			strcat(allmods, c);
+			modmask &= ~table->value;
+		}
+		else if (mask == table->value)
+		{
+			/* exact match */
+			strcpy(allmods, c);
+			break;
+		}
+	}
+
+	return allmods;
+}
