@@ -25,7 +25,7 @@
 /* The "extended" buttons do not provide the full functionality because X has
  * no bit mask value for them.  Things like dragging windows don't work with
  * them. */
-#define NUMBER_OF_EXTENDED_MOUSE_BUTTONS   9
+#define NUMBER_OF_EXTENDED_MOUSE_BUTTONS   15
 #if NUMBER_OF_EXTENDED_MOUSE_BUTTONS > 31
 #error No more than 31 mouse buttons can be supported on 32 bit platforms
 #endif
@@ -248,8 +248,8 @@
 
 /*** movement ***/
 #define DEFAULT_OPAQUE_MOVE_SIZE           5 /* percent of window area */
-#define DEFAULT_SNAP_ATTRACTION            0
-#define DEFAULT_SNAP_ATTRACTION_MODE     0x3
+#define DEFAULT_SNAP_ATTRACTION            0 /* snap nothing */
+#define DEFAULT_SNAP_ATTRACTION_MODE     0x3 /* snap all */
 #define DEFAULT_SNAP_GRID_X                1 /* pixels */
 #define DEFAULT_SNAP_GRID_Y                1 /* pixels */
 
@@ -317,6 +317,13 @@
 #define MAX_RESOURCE_LEN                 200 /* characters */
 #define MAX_CLASS_LEN                    200 /* characters */
 
+/* The default title and icon title in case the user doesn't supply one. */
+#define DEFAULT_TITLE_FORMAT "%n"
+#define DEFAULT_ICON_TITLE_FORMAT "%i"
+
+/* Set the maximum size a visible name can be. */
+#define MAX_VISIBLE_NAME_LEN		4096
+
 /*** numbered window names ***/
 #define MAX_WINDOW_NAME_NUMBER           999
 #define MAX_WINDOW_NAME_NUMBER_DIGITS      3 /* number/digits of above number */
