@@ -10,8 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 /*
@@ -44,12 +43,15 @@
 #include <X11/Intrinsic.h>
 #include <X11/Shell.h>
 
-#include <libs/fvwmlib.h>
-#include <libs/Picture.h>
-#include <libs/Module.h>
-#include <libs/FScreen.h>
-#include <libs/FShape.h>
-#include <libs/FRenderInit.h>
+#include "libs/fvwmlib.h"
+#include "libs/Picture.h"
+#include "libs/Module.h"
+#include "libs/FScreen.h"
+#include "libs/FShape.h"
+#include "libs/FRenderInit.h"
+#include "libs/Graphics.h"
+#include "libs/Parse.h"
+#include "libs/Strings.h"
 
 /* migo (16-Sep-1999): How about to do this configurable? */
 /*#include "fvwm-logo-old.xpm"*/
@@ -153,10 +155,7 @@ int main(int argc, char **argv)
   Root = RootWindow(dpy, screen);
   x_fd = XConnectionNumber(dpy);
 
-  PictureInitCMap(dpy);
-  FScreenInit(dpy);
-  FShapeInit(dpy);
-  FRenderInit(dpy);
+  flib_init_graphics(dpy);
   /* SetMessageMask(fd, M_CONFIG_INFO | M_END_CONFIG_INFO  | M_SENDCONFIG); */
   SetMessageMask(fd, M_CONFIG_INFO | M_END_CONFIG_INFO);
   parseOptions(fd);
