@@ -1,15 +1,10 @@
+/* -*-c-*- */
 /*
  * FvwmButtons, copyright 1996, Jarl Totland
  *
  * This module, and the entire GoodStuff program, and the concept for
  * interfacing this module to the Window Manager, are all original work
  * by Robert Nation
- *
- * Copyright 1993, Robert Nation. No guarantees or warantees or anything
- * are provided or implied in any way whatsoever. Use this program at your
- * own risk. Permission to use this program for any purpose is given,
- * as long as the copyright is kept intact.
- *
  */
 
 /* This program is free software; you can redistribute it and/or modify
@@ -23,10 +18,9 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 void ParseConfiguration(button_info *ub);
-void parse_window_geometry(char *geom);
+void parse_window_geometry(char *geom, int is_button_geometry);
 char *expand_action(char *in_action, button_info *b);
