@@ -20,8 +20,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 #include "config.h"
@@ -532,7 +531,7 @@ void usage(void)
   fprintf (stderr,
 	   "  -v                  print version number\n");
   fprintf (stderr,
-	   "  -w <micro sec>      waiting time for the reponse from fvwm\n");
+	   "  -w <micro sec>      waiting time for the response from fvwm\n");
   fprintf (stderr, "\nDefault fifo names are ~/.%sC and ~/.%sM\n",
 	   MYNAME, MYNAME);
   fprintf (stderr, "Default waiting time is 500,000 us\n");
