@@ -16,8 +16,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# along with this program; if not, see: <http://www.gnu.org/licenses/>
 
 . ./FvwmCommand.sh
 
@@ -28,16 +27,15 @@ elif [ "$1" = 'kb' ] ; then
 elif [ "$1" = 'r' ] ; then
   n=$2
   DestroyModuleConfig '*FvwmButtonsRows'
-  AddModuleConfig "*FvwmButtonsRows $n"
+  FvwmCommand "*FvwmButtonsRows $n"
 elif [ "$1" = 'c' ] ; then
   n=$2
   DestroyModuleConfig '*FvwmButtonsColumns'
-  AddModuleConfig "*FvwmButtonsColumns $n"
+  FvwmCommand "*FvwmButtonsColumns $n"
 else
  echo " arg1  b  to invoke FvwmButtons"
  echo "       kb to kill FvwmButtons"
- ehco "       r  to change button rows"
+ echo "       r  to change button rows"
  echo "       c  to change button columns"
 
 fi
-
