@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /*
  * ParseComand.c was originally part of FvwmForm.c.
  *
@@ -22,8 +23,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 #include "config.h"
@@ -49,7 +49,7 @@ static int N = 8;
 char * ParseCommand (int dn, char *sp, char end, int *dn1, char **sp1)
 {
   static char var[256];
-  char c, x, *wp, *cp, *vp;
+  char c, x, *cp, *vp;
   int j, dn2;
   int added_sel;
   Item *item;
@@ -70,7 +70,7 @@ char * ParseCommand (int dn, char *sp, char end, int *dn1, char **sp1)
     if (c == '$') {  /* variable */
       if (*sp != '(')
 	goto normal_char;
-      wp = ++sp;
+      ++sp;
       vp = var;
       while (1) {
 	x = *(sp++);
