@@ -10,13 +10,13 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 #include "config.h"
 
 #include <limits.h>
+#include "libs/wild.h"
 #include "FvwmIconMan.h"
 
 #define HASHTAB_SIZE 257
@@ -173,10 +173,7 @@ int check_resolution(WinManager *manager, WinData *win)
       flag = 1;
     } else if (win->desknum == globals.desknum) {
       /* win and screen intersect if they are not disjoint in x and y */
-      flag = RECTANGLES_INTERSECT(
-	g.x, g.y, g.width, g.height,
-	manager->managed_g.x, manager->managed_g.y,
-	manager->managed_g.width, manager->managed_g.height);
+      flag = fvwmrect_do_rectangles_intersect(&g, &manager->managed_g);
     }
     break;
 
@@ -186,10 +183,7 @@ int check_resolution(WinManager *manager, WinData *win)
   case SHOW_SCREEN:
     if (win->desknum == globals.desknum) {
       /* win and screen intersect if they are not disjoint in x and y */
-      flag = RECTANGLES_INTERSECT(
-	g.x, g.y, g.width, g.height,
-	manager->managed_g.x, manager->managed_g.y,
-	manager->managed_g.width, manager->managed_g.height);
+      flag = fvwmrect_do_rectangles_intersect(&g, &manager->managed_g);
     }
     break;
   }
@@ -219,7 +213,7 @@ static int iconmanager_show (WinManager *man, char *tname, char *iname,
     ConsoleDebug (WINLIST, "Matching: %s\n", string->string);
     if (matches_string (string->type, string->string, tname, iname,
 			rname, cname)) {
-      ConsoleDebug (WINLIST, "Dont show\n");
+      ConsoleDebug (WINLIST, "Don't show\n");
       in_dontshowlist = 1;
       break;
     }
