@@ -2,12 +2,7 @@
 /* This module, and the entire FvwmM4 program, and the concept for
  * interfacing this module to the Window Manager, are all original work
  * by Robert Nation
- *
- * Copyright 1994, Robert Nation
- *  No guarantees or warantees or anything
- * are provided or implied in any way whatsoever. Use this program at your
- * own risk. Permission to use this program for any purpose is given,
- * as long as the copyright is kept intact. */
+ */
 
 /* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,8 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 #include "config.h"
@@ -45,6 +39,9 @@
 #include <X11/Intrinsic.h>
 
 #include "libs/Module.h"
+#include "libs/Strings.h"
+#include "libs/System.h"
+#include "libs/fvwm_sys_stat.h"
 
 #include "FvwmM4.h"
 #include "libs/fvwmlib.h"
@@ -281,7 +278,6 @@ static char *m4_defs(
 	FILE *tmpf;
 	struct passwd *pwent;
 	int fd;
-	int ScreenWidth, ScreenHeight;
 	int Mscreen;
 
 	/* Generate a temporary filename.  Honor the TMPDIR environment variable,
@@ -317,7 +313,10 @@ static char *m4_defs(
 		 */
 		/* first try to unlink it */
 		unlink(tmp_name);
-		if ((fd = open(tmp_name, O_WRONLY|O_EXCL|O_CREAT, 0600)) < 0)
+		fd = open(
+			tmp_name, O_WRONLY|O_EXCL|O_CREAT,
+			FVWM_S_IRUSR | FVWM_S_IWUSR);
+		if (fd < 0)
 		{
 			fprintf(
 				stderr,
@@ -404,8 +403,6 @@ static char *m4_defs(
 	Mscreen= DefaultScreen(display);
 	fputs(MkNum("SCREEN", Mscreen), tmpf);
 
-	ScreenWidth = DisplayWidth(display,Mscreen);
-	ScreenHeight = DisplayHeight(display,Mscreen);
 	fputs(MkNum("WIDTH", DisplayWidth(display,Mscreen)), tmpf);
 	fputs(MkNum("HEIGHT", DisplayHeight(display,Mscreen)), tmpf);
 
