@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 
@@ -612,6 +611,7 @@ static Bool parse_options(void)
 		}
 		else if (StrEquals(resource, "Group"))
 		{
+			ProxyGroup* proxygroup;
 			char groupname[128];
 			char directive[128];
 			char tail[128];
@@ -619,7 +619,6 @@ static Bool parse_options(void)
 			int bytes=0;
 			(void)sscanf(tline, "\"%[^\"]\"%s%n",
 				groupname,directive,&bytes);
-			ProxyGroup* proxygroup;
 
 			strncpy(tail,&tline[bytes],128);
 			tail[127]=0;
@@ -1063,7 +1062,11 @@ static int GetParentProcessId(int pid)
 	{
 		return 0;
 	}
-	(void)fread(resultBuffer,32,1,statusfile);
+	{
+		int n;
+		n = fread(resultBuffer,32,1,statusfile);
+		(void)n;
+	}
 	sscanf(resultBuffer,"%*d %*[^)]) %*s %d",&ppid);
 	fclose(statusfile);
 	return ppid;
