@@ -10,8 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 #include "config.h"
@@ -25,6 +24,8 @@
 #include "libs/wcontext.h"
 #include "libs/modifiers.h"
 #include "libs/Module.h"
+#include "libs/ColorUtils.h"
+#include "libs/Strings.h"
 #ifdef HAVE_GETPWUID
 #  include <pwd.h>
 #endif
@@ -32,7 +33,7 @@
 extern int fd[2];
 extern Window ref;
 
-void (*TabCom[27]) (int NbArg,long *TabArg);
+void (*TabCom[29]) (int NbArg,long *TabArg);
 char *(*TabFunc[27]) (int *NbArg, long *TabArg);
 int (*TabComp[7]) (char *arg1,char *arg2);
 
@@ -108,9 +109,11 @@ static int InfEq(char *arg1,char *arg2)
 
 static int Equal(char *arg1,char *arg2)
 {
-  int an1,an2;
-  an1=atoi(arg1);
-  an2=atoi(arg2);
+  int n;
+
+  n = atoi(arg1);
+  n = atoi(arg2);
+  (void)n;
   return (strcmp(arg1,arg2)==0);
 }
 
@@ -132,9 +135,11 @@ static int Sup(char *arg1,char *arg2)
 
 static int Diff(char *arg1,char *arg2)
 {
-  int an1,an2;
-  an1=atoi(arg1);
-  an2=atoi(arg2);
+  int n;
+
+  n = atoi(arg1);
+  n = atoi(arg2);
+  (void)n;
   return (strcmp(arg1,arg2)!=0);
 }
 
@@ -324,7 +329,6 @@ static char *FuncGetOutput(int *NbArg, long *TabArg)
   int line,index,i=2,j=0,k,NewWord;
   FILE *f;
   int maxsize=32000;
-  int size;
 
   (*NbArg)++;
   cmndbuf=CalcArg(TabArg,NbArg);
@@ -348,10 +352,13 @@ static char *FuncGetOutput(int *NbArg, long *TabArg)
     }
     else
     {
+      int n;
+
       if (strcmp(Command,"None"))
 	free(BufCom);
       BufCom = (char*)safecalloc(sizeof(char),maxsize);
-      size = fread(BufCom,1,maxsize,f);
+      n = fread(BufCom,1,maxsize,f);
+      (void)n;
       pclose(f);
       strncpy(Command,cmndbuf,255);
       TimeCom=time(NULL);
@@ -621,12 +628,17 @@ static char *LaunchScript (int *NbArg,long *TabArg)
   free(arg);
 
   /* Envoi de la commande */
-  write(fd[0], &ref, sizeof(Window));
-  leng = strlen(execstr);
-  write(fd[0], &leng, sizeof(unsigned long));
-  write(fd[0], execstr, leng);
-  leng = 1;
-  write(fd[0], &leng, sizeof(unsigned long));
+  {
+    int n;
+
+    n = write(fd[0], &ref, sizeof(Window));
+    (void)n;
+    leng = strlen(execstr);
+    n = write(fd[0], &leng, sizeof(unsigned long));
+    n = write(fd[0], execstr, leng);
+    leng = 1;
+    n = write(fd[0], &leng, sizeof(unsigned long));
+  }
   free(execstr);
 
   /* Retourne l'id du fils */
@@ -781,7 +793,7 @@ static char *FuncSendMsgAndGet(int *NbArg,long *TabArg)
   FILE *f;
   struct timeval timeout;
 
-  /* comunication name */
+  /* communication name */
   (*NbArg)++;
   com_name=CalcArg(TabArg,NbArg);
   /* the command send to the receiver */
@@ -838,7 +850,7 @@ static char *FuncSendMsgAndGet(int *NbArg,long *TabArg)
       if (i > IN_FIFO_NBR_OF_TRY)
       {
 	fprintf(stderr,
-	 "[%s][GetMsgAndGet]: <<WARNING>> No in fifo %s for comunication %s\n",
+	 "[%s][GetMsgAndGet]: <<WARNING>> No in fifo %s for communication %s\n",
 	  ScriptName,in_fifo,com_name);
 	close(filedes);
 	err = 1;
@@ -870,8 +882,11 @@ static char *FuncSendMsgAndGet(int *NbArg,long *TabArg)
     {
       if ((f = fopen (out_fifo, "r")) != NULL)
       {
+	int n;
+
 	buf=(char*)safecalloc(sizeof(char),maxsize);
-	fread(buf,1,maxsize,f);
+	n = fread(buf,1,maxsize,f);
+	(void)n;
 	fclose (f);
       }
       else
@@ -892,7 +907,7 @@ static char *FuncSendMsgAndGet(int *NbArg,long *TabArg)
       if (i > OUT_FIFO_NBR_OF_TRY)
       {
 	fprintf(stderr,
-	 "[%s][GetMsgAndGet]: <<WARNING>>: No out fifo %s for comunication %s\n",
+	 "[%s][GetMsgAndGet]: <<WARNING>>: No out fifo %s for communication %s\n",
 	 ScriptName,out_fifo,com_name);
 	err = 1;
 	break;
@@ -1015,12 +1030,17 @@ static void Exec (int NbArg,long *TabArg)
     free(tempstr);
   }
 
-  write(fd[0], &ref, sizeof(Window));
-  leng = strlen(execstr);
-  write(fd[0], &leng, sizeof(unsigned long));
-  write(fd[0], execstr, leng);
-  leng = 1;
-  write(fd[0], &leng, sizeof(unsigned long));
+  {
+    int n;
+
+    n = write(fd[0], &ref, sizeof(Window));
+    (void)n;
+    leng = strlen(execstr);
+    n = write(fd[0], &leng, sizeof(unsigned long));
+    n = write(fd[0], execstr, leng);
+    leng = 1;
+    n = write(fd[0], &leng, sizeof(unsigned long));
+  }
   free(execstr);
 }
 
@@ -1433,6 +1453,46 @@ static void ChangeColorset (int NbArg,long *TabArg)
   free(arg[1]);
 }
 
+/* ChangeWindowTitle */
+static void ChangeWindowTitle(int NbArg,long * TabArg){
+
+  char *arg;
+  int tmpVal=NbArg-1;
+
+  arg=CalcArg(TabArg,&tmpVal);
+  XChangeProperty(
+	  dpy, x11base->win, XA_WM_NAME, XA_STRING, 8, PropModeReplace,
+	  (unsigned char*)arg, strlen(arg));
+  free(arg);
+}
+
+
+/* ChangeWindowTitleFromArg */
+static void ChangeWindowTitleFromArg(int NbArg,long * TabArg){
+
+  char *arg;
+  int argVal;
+  int tmpVal=NbArg-1;
+
+  arg=CalcArg(TabArg,&tmpVal);
+  argVal = atoi(arg);
+  free(arg);
+
+  if(x11base->TabArg[argVal]!=NULL){
+    arg =  (char*)safecalloc(strlen(x11base->TabArg[argVal])+1,sizeof(char));
+    arg = strcpy(arg,x11base->TabArg[argVal]);
+  }else{
+    arg =  (char*)safecalloc(1,sizeof(char));
+    arg = strcpy(arg,"");
+  }
+
+  XChangeProperty(
+	  dpy, x11base->win, XA_WM_NAME, XA_STRING, 8, PropModeReplace,
+	  (unsigned char*)arg, strlen(arg));
+  free(arg);
+}
+
+
 /* SetVar */
 static void SetVar (int NbArg,long *TabArg)
 {
@@ -1539,14 +1599,12 @@ static void IfThen (int NbArg,long *TabArg)
 /* Instruction boucle **/
 static void Loop (int NbArg,long *TabArg)
 {
-  int IdVar;
   char *arg[2];
   int limit[2];
   int i;
   int CurrArg=0;
 
   /* le premier argument est une variable */
-  IdVar = TabArg[0];
   /*On ajuste la taille de la var pour contenir un nombre */
   TabVVar[TabArg[0]] = (char*)saferealloc(TabVVar[TabArg[0]],sizeof(char)*10);
   /* Calcul des 2 autres arguments */
@@ -1888,6 +1946,8 @@ void InitCom(void)
   TabCom[24]=ChangeColorset;
   TabCom[25]=Key;
   TabCom[26]=ChangeLocaleTitle;
+  TabCom[27]=ChangeWindowTitle;
+  TabCom[28]=ChangeWindowTitleFromArg;
 
   /* Fonction */
   TabFunc[1]=FuncGetValue;
