@@ -10,12 +10,14 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 #include "config.h"
 
+#include "libs/fvwmlib.h"
+#include "libs/ColorUtils.h"
+#include "libs/Strings.h"
 #include "Tools.h"
 
 extern int fd[2];
@@ -77,7 +79,7 @@ void InitSwallow(struct XObj *xobj)
 	static char *orig_sm_env = NULL;
 	static int len = 0;
 	static Bool sm_initialized = False;
-	static Bool session_manager = False; 
+	static Bool session_manager = False;
 	char *cmd;
 
 	/* Enregistrement des couleurs et de la police */
@@ -135,7 +137,7 @@ void InitSwallow(struct XObj *xobj)
 		len = 45 + strlen(my_sm_env) + strlen(orig_sm_env);
 	}
 
-	cmd = safemalloc(len + strlen(xobj->swallow)); 
+	cmd = safemalloc(len + strlen(xobj->swallow));
 	sprintf(
 		cmd,
 		"FSMExecFuncWithSessionManagment \"%s\" \"%s\" \"%s\"",
