@@ -12,7 +12,7 @@
 
 if grep -q -i '^ISRELEASED="yes"' ./configure.ac; then
 	# A release build.  Strip the git information off the tag name.
-	git describe --tags --abbrev=0 2>/dev/null || echo "2.6.8"
+	echo "2.7.0"
 else
 	git describe --always --long --dirty
 fi
